@@ -25,7 +25,7 @@ Microsoft::AdCenter::NotificationManagementService - Service client for Microsof
         EndDate => ...
     );
 
-See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for detailed documentation for this service.
+See L<http://msdn.microsoft.com/en-us/library/ee730328%28v=MSADS.70%29.aspx> for detailed documentation for this service.
 
 =head1 METHODS
 
